Documentation
¶
Overview ¶
Package mocks provides shared mock implementations for testing across the application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockFS ¶
type MockFS struct {
Files map[string]bool // path -> isDir
RenameErr error
WalkErr error
WalkFnErr error // New field to simulate an error passed to the walk function.
RenameFrom string
RenameTo string
}
MockFS implements the FS interface for testing purposes.
type MockFileInfo ¶
MockFileInfo implements fs.FileInfo for our mock file system.
func (MockFileInfo) IsDir ¶
func (m MockFileInfo) IsDir() bool
IsDir returns true if the entry is a directory.
func (MockFileInfo) ModTime ¶
func (m MockFileInfo) ModTime() time.Time
ModTime returns the modification time.
func (MockFileInfo) Sys ¶
func (m MockFileInfo) Sys() interface{}
Sys returns the underlying data source.
Click to show internal directories.
Click to hide internal directories.