package
Version:
v1.2.5
Opens a new window with list of versions in this module.
Published: Apr 23, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package validate provides functions for validating the input configuration
for the repo-slice tool.
ValidateInputs checks that the source and manifest paths are valid.
It depends on the FS interface, not a concrete file system.
type Config struct {
ManifestPath string
SourcePath string
}
Config represents the input configuration that needs validation.
FS defines an interface for file system operations, allowing for mock
implementations in tests. This adheres to the Dependency Inversion Principle.
LiveFS is a concrete implementation of the FS interface that uses the
standard library's os package.
Stat performs the Stat operation using the os package.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.